@@ -1,5 +1,4 @@
 tv.home <- function() {
-
   if(is.null(getOption('tv_home'))) {
     if(.Platform$OS.type == "unix") if(file.access(paste(Sys.getenv('HOME'),'/.wine/drive_c/Turbowin/Popup/tvscale.dbf', sep='')) == 0)   tv_home <- file.path(Sys.getenv('HOME'),'.wine/drive_c/Turbowin') else
       tv_home <- NA
@@ -16,7 +15,7 @@ tv.home <- function() {
    cat('\nNo Turbowin installation path found. \n')
    ANSWER <- readline("Should I use \n 1) the vegdata package path, or \n 2) a temporary folder? ")
    tv_home <- switch(substr(ANSWER, 1, 1),
-         "1" = file.path(path.package('vegdata'), 'Species'),
+         "1" = file.path(path.package('vegdata'), 'tvdata', 'Species'),
          tempdir()
    )
    for(d in c('Popup', 'Data', 'Species')) {
@@ -34,10 +33,10 @@ tv.home <- function() {
      file.copy(from =  list.files(file.path(path.package('vegdata'), 'tvdata', d), recursive=TRUE, full.names=TRUE, include.dirs=TRUE), to = file.path(tv_home, d))
    }
   }
-  cat('\n##########################################################',
-      '\nTurboveg root directory is set to', tv_home,
+  message('############################################################',
+      '\nTurboveg root directory is set to "', tv_home, '"',
       '\nIf you want to change this use: options(tv_home=\"<path_to_your_Turbowin_root>\")',
-      '\n##########################################################\n')
+      '\n############################################################')
   options(tv_home=tv_home)
   } else {
   tv_home <- getOption('tv_home')
